# function_name()

## How to use

1. ```python
   Code example
   ```

## Parameters

1. Required parameters:

   - Name:  
      Description
     - `type: Show type`
     - `default: Has it a default value`
     - `example: Add example` (Optional!)

2. Optional parameters
   - Name:  
      Description
     - `type: Show type`
     - `default: Has it a default value`

## Return value

- `type: boolean or string`
